@@ -18,7 +18,7 @@ WebAppView::WebAppView(const QString& appUrl) :
 
     // please call from javascript only
     //m_nativeServices->requestConnection();
-    connect(m_nativeServices, SIGNAL(stateChanged(QNetworkSession::State)), this, SLOT(stateChanged(QNetworkSession::State)));
+    //connect(m_nativeServices, SIGNAL(stateChanged(QNetworkSession::State)), this, SLOT(stateChanged(QNetworkSession::State)));
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
     layout->setSpacing(0);
